import PropTypes from "prop-types";
import React from "react";
import ReactCursorPosition from "react-cursor-position";

function Pointer({ x, y, active }) {
  const color = active ? "green" : "red";

  return (
    <div
      style={{
        position: "absolute",
        backgroundColor: color,
        cursor: "pointer",
        borderRadius: "100px",
        width: "10px",
        height: "10px",
        marginLeft: "-5px",
        marginTop: "-5px",
        left: x,
        top: y
      }}
    />
  );
}

class Image extends React.Component {
  state = {
    x: 0,
    y: 0
  };

  constructor(props) {
    super(props);

    this.node = React.createRef();
  }

  handleClick = e => {
    const posPercent = this.calcPercent(
      this.props.position.x,
      this.props.position.y
    );
    this.setState({ x: this.props.position.x, y: this.props.position.y });
    this.props.updatePos(posPercent.xPro, posPercent.yPro);
  };

  calcPercent = (x, y) => {
    const xPro = Math.floor(
      (x / this.node.current.getBoundingClientRect().width) * 100
    );
    const yPro = Math.floor(
      (y / this.node.current.getBoundingClientRect().height) * 100
    );

    return { xPro, yPro };
  };

  imgLoad = () => {
    const x =
      (this.node.current.getBoundingClientRect().width / 100) * this.props.xPro;
    const y =
      (this.node.current.getBoundingClientRect().height / 100) *
      this.props.yPro;

    console.log("in", x, y);
    this.setState({ x: x, y: y });
  };

  render() {
    return (
      <div
        style={{ position: "relative", cursor: "pointer", minWidth: '100%', minHeight: '100px', backgroundColor: 'lightgray' }}
        onClick={this.handleClick}>
        <img src={this.props.img} onLoad={this.imgLoad} ref={this.node} />
        <Pointer x={this.state.x} y={this.state.y} />
      </div>
    );
  }
}
export default class Control extends React.Component {
  static propTypes = {
    onChange: PropTypes.func.isRequired,
    forID: PropTypes.string,
    value: PropTypes.node,
    classNameWrapper: PropTypes.string.isRequired
  };

  state = {
    img: ""
  };

  static defaultProps = {
    value: "50% 50%"
  };

  constructor(props) {
    super(props);
    this.node = React.createRef();
  }

  getImgSrc = () => {
    const imgNode = this.node.current.parentElement.parentElement.querySelector(
      "img"
    );

    if (imgNode) {
      this.setState({ img: imgNode.src });
    } else {
      console.log("No imgae");
      return "halllo";
    }
  };

  updatePos = (x, y) => {
    const posString = `${x}% ${y}%`;
    this.props.onChange(posString);
  };

  render() {
    const { forID, value, onChange, classNameWrapper } = this.props;
    const [xPro, yPro] = value.match(/\d{1,3}(?=%)/g);

    return (
      <div
        ref={this.node}
        id={forID}
        className={classNameWrapper}
        value={value || ""}
        onChange={e => onChange(e.target.value)}>
        <button
          className="nc-imageControl-chooseButton"
          style={{ margin: "20px", display: "inline" }}
          onClick={this.getImgSrc}>
          Lade Bild...
        </button>
        <span>Bitte "Bild laden", nachdem ein Bild ausgewählt wurde.</span>
        <ReactCursorPosition>
          <Image
            img={this.state.img}
            updatePos={this.updatePos}
            xPro={parseInt(xPro)}
            yPro={parseInt(yPro)}
          />
        </ReactCursorPosition>
      </div>
    );
  }
}
